/***************************************************************************
 * Speextalk
 * (C) Nicolas George - 2005-07-24
 * This code is distributed under the terms of the GNU GPL.
 * speextalk.h: common header
 ***************************************************************************/

#include <pthread.h>
#include <speex/speex.h>

#define MAX_PACKET_SIZE 4096

typedef struct {
    const SpeexMode *speex_mode;
    int sample_rate;
    char channels;
} audio_format_t;


/* speextalk.c */
extern const char *remote;
extern const char *service;
extern const char *capture_device;
extern const char *playback_device;
extern const char *comment;
extern int sock;
extern unsigned char recv_buffer[MAX_PACKET_SIZE];
extern int l_recv_buffer;
extern int audio_format_in;
extern int audio_format_out;
extern const audio_format_t const audio_formats[];
extern int speex_quality;
extern int speex_vbr;
extern int max_packet_size;
extern int max_packet_frames;
extern volatile int igain;
extern int packet_overhead;
extern volatile int power_out;
extern volatile int power_in;
extern volatile int bandwidth_out;
extern volatile int bandwidth_in;
extern volatile int running;
extern pthread_mutex_t global_mutex;

extern void fatal_system(const char *);
extern void update_power(volatile int *, short *, int);
extern void update_bandwidth(volatile int *, int *, unsigned *, int);
extern void check_audio_format(int, const char *);

/* encode.c */
extern void *encode_loop(void *);

/* decode.c */
extern void receive_packet(void);
extern void *decode_loop(void *);

/* handshake.c */
extern void start_handshake(void);
extern void wait_handshake(void);


/* soud_*.c */
extern void prepare_playing(int, int);
extern void prepare_recording(int, int);
extern int read_samples(short *, int);
extern int play_samples(short *, int);

/* interface_* */
extern void interface_init(void);
extern void interface_run(void);
extern void interface_print(const char *);
extern int interface_ask(const char *);
